@@ -12,6 +12,7 @@
 #include <unistd.h>
 #include <signal.h>
 #include <dirent.h>
+#include <locale.h>
 
 /* prototypes */
 static GtkWidget *get_saver_frame ();
@@ -196,6 +197,7 @@ main (int argc, char **argv)
         gchar *session_args[3];
         gint token, init_results;
 
+				setlocale(LC_ALL, "");
         bindtextdomain (PACKAGE, GNOMELOCALEDIR);
         textdomain (PACKAGE);
 
