@@ -19,6 +19,8 @@ static GtkWidget *last_theme = NULL;
 static GtkWidget *font_sel;
 static GtkWidget *font_cbox;
 static gboolean initial_preview;
+static GtkWidget *fatal_error_dialog;
+
 /* If this is TRUE, then we use the custom font */
 static gboolean initial_font_cbox;
 static gchar *initial_font;
@@ -33,6 +35,8 @@ click_ok(GtkWidget *widget, gpointer data);
 static void
 click_revert(GtkWidget *widget, gpointer data);
 static void
+click_cancel(GtkWidget *widget, gpointer data);
+static void
 click_entry(GtkWidget *widget, gpointer data);
 static void
 delete_entry(GtkWidget *widget, gpointer data);
@@ -315,7 +319,7 @@ make_main(void)
   gtk_signal_connect (GTK_OBJECT (capplet_widget), "revert",
 		      GTK_SIGNAL_FUNC (click_revert), NULL);
   gtk_signal_connect (GTK_OBJECT (capplet_widget), "cancel",
-		      GTK_SIGNAL_FUNC (click_revert), NULL);
+		      GTK_SIGNAL_FUNC (click_cancel), NULL);
   gtk_signal_connect (GTK_OBJECT (capplet_widget), "delete_event",
 		      GTK_SIGNAL_FUNC (delete_capplet), NULL);
   gtk_container_add (GTK_CONTAINER (capplet_widget), box);
@@ -372,7 +376,11 @@ click_try(GtkWidget *widget, gpointer data)
 {
   gchar *rc;
   gchar *dir;
+  gboolean result;
 
+  if (fatal_error_dialog)
+    return;
+  
 /*  if (current_theme == current_global_theme)
     return;*/
   widget = current_theme;
@@ -388,23 +396,35 @@ click_try(GtkWidget *widget, gpointer data)
   /* printf("%s\n", cmd); */
   send_reread();
   if (GTK_TOGGLE_BUTTON (font_cbox)->active)
+    result = use_theme(rc,
+		       gnome_font_picker_get_font_name (GNOME_FONT_PICKER (font_sel)));
+  else
+    result = use_theme(rc, NULL);
+
+  if (result)
     {
-      use_theme(rc,
-		gnome_font_picker_get_font_name (GNOME_FONT_PICKER (font_sel)));
+      gdk_error_trap_push ();
+      signal_apply_theme(widget);
+      gdk_flush();
+      /* system(cmd); */
+      gdk_error_trap_pop ();
     }
   else
     {
-      use_theme(rc, NULL);
+      /* Re-sensitize try/revert buttons */
+      capplet_widget_state_changed(CAPPLET_WIDGET (capplet_widget), TRUE);
     }
-  gdk_error_warnings = 0;
-  signal_apply_theme(widget);
-  gdk_flush();
-  /* system(cmd); */
-  gdk_error_warnings = 1;
+    
 }
 static void
 click_ok(GtkWidget *widget, gpointer data)
 {
+  if (fatal_error_dialog)
+    {
+      gnome_dialog_close (GNOME_DIALOG (fatal_error_dialog));
+      return;
+    }
+  
   click_try (widget, data);
   gnome_config_set_bool ("/theme-switcher-capplet/settings/auto",GTK_TOGGLE_BUTTON (auto_preview)->active);
   gnome_config_set_string ("/theme-switcher-capplet/settings/theme", gtk_object_get_data (GTK_OBJECT (current_theme), "name"));
@@ -419,6 +439,9 @@ click_revert(GtkWidget *widget, gpointer data)
 {
   gchar *rc;
 
+  if (fatal_error_dialog)
+    return;
+  
   widget = initial_theme;
   if (!widget)
     /* we hope this doesn't happen, but it could if things
@@ -434,15 +457,22 @@ click_revert(GtkWidget *widget, gpointer data)
 		 gnome_font_picker_get_font_name (GNOME_FONT_PICKER (font_sel)))))
     {
       
-      /* This if statement is magic to determine if we want to reset the system theme.
+      /* The above statement is magic to determine if we want to reset the system theme.
        * It can almost certainly be cleaned up if needed.  Basicly, it sees if anything has
        * or if the theme has been set.. */
       send_reread();
-      use_theme(rc, initial_font);
-      gdk_error_warnings = 0;
-      signal_apply_theme(widget);
-      gdk_flush();
-      gdk_error_warnings = 1;
+      if (use_theme(rc, initial_font))
+	{
+	  gdk_error_trap_push();
+	  signal_apply_theme(widget);
+	  gdk_flush();
+	  gdk_error_trap_pop();
+	}
+      else
+	{
+	  /* Re-sensitize try/revert buttons */
+	  capplet_widget_state_changed(CAPPLET_WIDGET (capplet_widget), TRUE);
+	}
     }
   current_global_theme = widget;
   ignore_change = TRUE;
@@ -464,6 +494,20 @@ click_revert(GtkWidget *widget, gpointer data)
   ignore_change = FALSE;
   current_theme = initial_theme;
 }
+
+static void
+click_cancel(GtkWidget *widget, gpointer data)
+{
+  if (fatal_error_dialog)
+    {
+      gnome_dialog_close (GNOME_DIALOG (fatal_error_dialog));
+      return;
+    }
+  
+  click_revert (widget, data);
+}
+  
+
 static void
 click_entry(GtkWidget *widget, gpointer data)
 {
@@ -643,3 +687,32 @@ update_theme_entries(GtkWidget *disp_list)
   if (current_theme == NULL)
     ;
 }
+
+void
+show_error (const char *string, gboolean fatal)
+{
+  GtkWidget *dialog;
+  GtkWidget *hack_widget;
+
+  dialog = gnome_message_box_new (string, GNOME_MESSAGE_BOX_ERROR,
+				  GNOME_STOCK_BUTTON_OK, NULL);
+  
+  /* Kids, don't try this at home */
+  /* this is pretty evil... <-:  */
+  hack_widget = GNOME_DIALOG (dialog)->vbox;
+  hack_widget = ((GtkBoxChild *) GTK_BOX (hack_widget)->children->data)->widget;
+  hack_widget = ((GtkBoxChild *) GTK_BOX (hack_widget)->children->next->data)->widget;
+  
+  gtk_label_set_line_wrap (GTK_LABEL (hack_widget), TRUE);
+
+  if (fatal)
+    {
+      fatal_error_dialog = dialog;
+      
+      gtk_widget_set_sensitive (capplet_widget, FALSE);
+      gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
+      delete_capplet (NULL, NULL, NULL);
+    }
+  else
+    gtk_widget_show (dialog);
+}
