@@ -23,6 +23,7 @@
  */
 
 #include <config.h>
+#include <locale.h>
 #include "capplet-widget.h"
 
 static GtkWidget *capplet;
@@ -564,6 +565,7 @@ main (int argc, char **argv)
 {
 	GtkWidget *the_capplet;
 
+	setlocale(LC_ALL, "");
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
 	changing = TRUE;
